@@ -28,7 +28,7 @@ def Test(
     argsOfCallAfter = TEST_VALUE_NOT_SET,
     kwargsOfCallAfter = TEST_VALUE_NOT_SET,
     returns = None,
-    inspectGlobals = False,
+    inspectGlobals= True,
     logResult = True,
     **outerKwargs
 ) :
@@ -40,7 +40,9 @@ def Test(
             handleBefore(resourceInstanceMethod, callBefore, argsOfCallBefore, kwargsOfCallBefore, returns, inspectGlobals)
             originalEnvironmentVariables, originalActiveEnvironment = AnnotationHelper.getOriginalEnvironmentVariables(environmentVariables)
             try :
+                inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'is about to run')
                 methodReturn = resourceInstanceMethod(*innerArgs,**innerKwargs)
+                inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'just run')
             except Exception as exception :
                 methodReturnException = exception
             AnnotationHelper.resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables, originalActiveEnvironment)
@@ -50,16 +52,11 @@ def Test(
         return innerResourceInstanceMethod
     return innerMethodWrapper
 
-def inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, tense) :
-    if inspectGlobals :
-        import globals
-        LogHelper.printDebug(f'''Inspection: {globals.getGlobalsInstance(muteLogs=inspectGlobals)} globals instance {tense} {ReflectionHelper.getMethodModuleNameDotName(resourceInstanceMethod)}''', condition=inspectGlobals, newLine=False, margin=False)
-
 def handleBefore(resourceInstanceMethod, actionClass, args, kwargs, returns, inspectGlobals) :
-    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'will run')
+    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'will impartialy observe')
     LogHelper.test(resourceInstanceMethod, 'Test started')
     actionHandlerException = handle(resourceInstanceMethod, actionClass, args, kwargs, returns, BEFORE_THE_TEST, RETURN_VALUE_FROM_CALL_BEFORE)
-    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'running')
+    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'will run')
     if ObjectHelper.isNotNone(actionHandlerException) :
         raise actionHandlerException
 
@@ -68,10 +65,10 @@ def handleAfter(resourceInstanceMethod, actionClass, args, kwargs, returns, meth
         LogHelper.printSuccess(f'{ReflectionHelper.getMethodModuleNameDotName(resourceInstanceMethod)} test succeed', condition=logResult)
     else :
         LogHelper.printError(f'{ReflectionHelper.getMethodModuleNameDotName(resourceInstanceMethod)} test failed', condition=logResult, exception=methodReturnException)
-    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'still running')
+    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'did run')
     actionHandlerException = handle(resourceInstanceMethod, actionClass, args, kwargs, returns, AFTER_THE_TEST, RETURN_VALUE_FROM_CALL_AFTER)
     LogHelper.test(resourceInstanceMethod, 'Test completed')
-    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'did run')
+    inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, 'impartialy observed')
     if ObjectHelper.isNotNone(methodReturnException) or ObjectHelper.isNotNone(actionHandlerException) :
         if ObjectHelper.isNotNone(methodReturnException) and ObjectHelper.isNotNone(actionHandlerException) :
             raise Exception(f'{LogHelper.getExceptionMessage(methodReturnException)}. Followed by: {LogHelper.getExceptionMessage(actionHandlerException)}')
@@ -121,3 +118,8 @@ def returnsValueIsPresent(returns) :
     if not isPresent :
         LogHelper.test(returnsValueIsPresent, f'the key "returns" from {ReflectionHelper.getMethodModuleNameDotName(Test)} annotation call was not defined')
     return isPresent
+
+def inspectGlobalsIfNeeded(inspectGlobals, resourceInstanceMethod, tense) :
+    if inspectGlobals :
+        import globals
+        LogHelper.printDebug(f'''Inspection: {globals.getGlobalsInstance(muteLogs=inspectGlobals)} globals instance {tense} {ReflectionHelper.getMethodModuleNameDotName(resourceInstanceMethod)}''', condition=inspectGlobals, newLine=False, margin=False)
